# CS207 Final Project Repository
[![Build Status](https://travis-ci.com/cs207-f18-WIRS/cs207-FinalProject.svg?branch=master&service=github)](https://travis-ci.com/cs207-f18-WIRS/cs207-FinalProject)

[![Coverage Status](https://coveralls.io/repos/github/cs207-f18-WIRS/cs207-FinalProject/badge.svg?branch=master&service=github)](https://coveralls.io/github/cs207-f18-WIRS/cs207-FinalProject?branch=master)


This repository contains the Final Project Deliverable on Automatic Differentiation for the Harvard Course CS 207: Systems Development for Computational Science. 
  - [```Github Repository```](https://github.com/cs207-f18-WIRS/cs207-FinalProject)
  - [```PyPi Python Package Index distribution: 'AD-cs207'```](https://pypi.org/project/AD-cs207/) 

## Documentation can be found at [```docs```](https://github.com/cs207-f18-WIRS/cs207-FinalProject/tree/master/docs):
  - [```docs/How-to-install-and-use.md:```](https://github.com/cs207-f18-WIRS/cs207-FinalProject/blob/master/docs/How-to-install-and-use.md) Explanation on how to install and use the package.
  - [```docs/milestone2.ipynb:```](https://github.com/cs207-f18-WIRS/cs207-FinalProject/blob/master/docs/milestone2.ipynb) Automatic Differentiation package documentation.
  - [```docs/How-to-package.md:```](https://github.com/cs207-f18-WIRS/cs207-FinalProject/blob/master/docs/How-to-package.md) Explanation how the package was distributed.
  - [```Course Project discription```](https://iacs-cs-207.github.io/cs207-F18/project.html) : Overview of the instruction on the project.

## Course information:
  - [```Main course website```](https://iacs-cs-207.github.io/cs207-F18/) : Check this site for all course-related policies including the syllabus, course schedule, and project policies.
  - [```GitHub Repo```](https://github.com/IACS-CS-207/cs207-F18) : All course materials will be released on GitHub.

## Contributors (alphabetic):
  - FELDHAUS Isabelle 
  - JIANG Shenghao 
  - STRUYVEN Robbert
  - WANG William
